Author: mthl
Date: Sat Jul 13 21:42:19 2019
New Revision: 1863023
URL:
http://svn.apache.org/viewvc?rev=1863023&view=revLog:
Improved: Pass directly the loaders to ‘loadContainersFromConfigurations’
(OFBIZ-11100)
Since only the loaders are used from the configuration, it is better
to pass those directly as a parameter to the
‘loadContainersFromConfigurations’ method instead of the full
configuration object.
Modified:
ofbiz/ofbiz-framework/trunk/framework/base/src/main/java/org/apache/ofbiz/base/container/ContainerLoader.java
Modified: ofbiz/ofbiz-framework/trunk/framework/base/src/main/java/org/apache/ofbiz/base/container/ContainerLoader.java
URL:
http://svn.apache.org/viewvc/ofbiz/ofbiz-framework/trunk/framework/base/src/main/java/org/apache/ofbiz/base/container/ContainerLoader.java?rev=1863023&r1=1863022&r2=1863023&view=diff==============================================================================
--- ofbiz/ofbiz-framework/trunk/framework/base/src/main/java/org/apache/ofbiz/base/container/ContainerLoader.java (original)
+++ ofbiz/ofbiz-framework/trunk/framework/base/src/main/java/org/apache/ofbiz/base/container/ContainerLoader.java Sat Jul 13 21:42:19 2019
@@ -72,7 +72,7 @@ public class ContainerLoader {
// Load containers defined in components.
Debug.logInfo("[Startup] Loading containers...", module);
- loadedContainers.addAll(loadContainersFromConfigurations(config, ofbizCommands));
+ loadedContainers.addAll(loadContainersFromConfigurations(config.loaders, ofbizCommands));
// Start all containers loaded from above steps
startLoadedContainers();
@@ -93,16 +93,16 @@ public class ContainerLoader {
/**
* Loads the available containers which are matching the configured loaders.
*
* @param config the configuration defining the loaders to match
* @param ofbizCommands the parsed commands line arguments used by the containers
* @return a list of loaded containers.
* @throws StartupException when a container fails to load.
*/
- private static List<Container> loadContainersFromConfigurations(Config config, List<StartupCommand> ofbizCommands)
- throws StartupException {
+ private static List<Container> loadContainersFromConfigurations(Collection<String> loaders,
+ List<StartupCommand> ofbizCommands) throws StartupException {
List<Container> loadContainers = new ArrayList<>();
for (ContainerConfig.Configuration containerCfg : ComponentConfig.getAllConfigurations()) {
- if (intersects(containerCfg.loaders, config.loaders)) {
+ if (intersects(containerCfg.loaders, loaders)) {
Debug.logInfo("Loading container: " + containerCfg.name, module);
Container tmpContainer = loadContainer(containerCfg, ofbizCommands);
loadContainers.add(tmpContainer);
@@ -93,16 +93,16 @@ public class ContainerLoader {
* Loads the available containers which are matching the configured loaders.
*
- * @param config the configuration defining the loaders to match
+ * @param loaders the collection of loaders to match
* @param ofbizCommands the parsed commands line arguments used by the containers
* @return a list of loaded containers.